@@ -48,7 +48,7 @@ SOFTWARE.
 ******************************************************************/
 
 /*
- * $Id: main.c,v 1.8 2001/04/29 22:47:48 jon Exp $
+ * $Id: main.c,v 1.13 2004/09/11 19:23:33 jon Exp $
  */
 
 #include <stdio.h>
@@ -63,7 +63,8 @@ SOFTWARE.
 #include "servermd.h"
 #include "site.h"
 #include "globals.h"
-#include "nasconfig.h"
+#include "nasconf.h"
+#include "release.h"
 
 extern void     OsInit(), InitClient(), ResetWellKnownSockets(),
                 Dispatch(), FreeAllResources();
@@ -90,12 +91,9 @@ NotImplemented()
 
 static FILE     *openConfigFile (char *path)
 {
-  static char   buf[1024];
   FILE *config;
 
-  strcat (buf, path);
-  strcat (buf, "nasd.conf");
-  if ((config = fopen (buf, "r")) != NULL)
+  if ((config = fopen (path, "r")) != NULL)
     return config;
   else
     return NULL;
@@ -108,6 +106,7 @@ main(argc, argv)
     char	*argv[];
 {
     int		i;
+    char    *config_file;
 
     /* Notice if we're restart.  Probably this is because we jumped through
      * uninitialized pointer */
@@ -119,8 +118,11 @@ main(argc, argv)
     /* Init the globals... */
     diaInitGlobals();
 
-				/* Now parse the config file */
-    if ((yyin = openConfigFile (NASCONFSEARCHPATH)) != NULL)
+    if ((config_file = FindConfigFile(argc, argv)) == NULL)
+        config_file = NASCONFSEARCHPATH"/nasd.conf";
+
+    /* Now parse the config file */
+    if ((yyin = openConfigFile (config_file)) != NULL)
       yyparse();
 
     /* These are needed by some routines which are called from interrupt
@@ -137,14 +139,20 @@ main(argc, argv)
     if (display == NULL)
       display = AuServerName();
 
-    /* We're running as a daemon, so close stdin, stdout and stderr
-       before we start the main loop */
+    if (NasConfig.DoVerbose)
+      {
+        printf("%s\n", release);
+        osLogMsg("%s\n", release);
+      }
 
-    close(0);
-    close(1);
+    if (NasConfig.DoDaemon)
+      {
+	osBecomeOrphan();
+	osBecomeDaemon();
 
-    if (!NasConfig.DoDebug)
-      close(2);			/* only close stderr if no debugging */
+	/* we could store pid info here... */
+	/* osStorePid() */
+      }
 
     /* And cd to / so we don't hold anything up; core files will also
        go there. */
