@@ -63,6 +63,24 @@ SOFTWARE.
  *
  *****************************************************************/
 
+#include "nasconf.h"
+
+#if defined(__CYGWIN__)
+#define S_IFSOCK        _IFSOCK
+#define S_IFMT          _IFMT
+
+#include <limits.h>
+#include <string.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <sys/stat.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <netdb.h>
+#endif 
+
+
+
 #include <audio/audio.h>
 #include <audio/Aproto.h>
 #ifndef _MINIX
@@ -192,8 +210,6 @@ typedef long CCID;      /* mask of indices into client socket table */
 #endif
 #endif
 
-extern Bool	allow_any_host;	/* simplistic access control */
-
 #ifdef SERVER_LOCALCONN
 #include <sys/stream.h>
 #include <sys/stropts.h>
@@ -347,7 +363,16 @@ open_tcp_socket ()
 #endif
     insock.sin_family = AF_INET;
     insock.sin_port = htons ((unsigned short)(AudioListenPort + atoi (display)));
-    insock.sin_addr.s_addr = htonl(INADDR_ANY);
+
+    if (NasConfig.LocalOnly)
+      {
+        insock.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+      }
+    else
+      {
+	insock.sin_addr.s_addr = htonl(INADDR_ANY);
+      }
+    
     retry = 20;
     while (bind(request, (struct sockaddr *) &insock, sizeof (insock)))
     {
@@ -508,8 +533,14 @@ open_unix_socket ()
 
 #ifdef X_UNIX_DIR
 # ifndef S_ISVTX
-#  define S_ISVTX   01000 
+#  define S_ISVTX   0 		/* shouldn't use it if not available */
 # endif                                  
+
+    /* JET - 2/23/2002 this is problematic when nasd is run as a
+      normal user and root has run nasd beforehand - ie: you can't
+      remove the old socket, but security is improved.  ideally nasd should
+      just remove the socket on termination (SIGINT)
+    */
     if (!mkdir (X_UNIX_DIR, 0777))
       chmod (X_UNIX_DIR, 0777 | S_ISVTX);
 #endif
@@ -543,8 +574,22 @@ open_unix_socket ()
     unlink (unsock.sun_path);
     if ((request = socket (AF_UNIX, SOCK_STREAM, 0)) < 0) 
     {
-	Error ("Creating Unix socket");
-	return -1;
+      char *buffer;
+      int i;                                                                  
+      
+      i = strlen(unsock.sun_path);                                            
+      buffer = (char *)malloc(i + 80);                                                
+      if (buffer)
+        {
+          sprintf(buffer, "Error creating unix socket: %s\n", 
+                  unsock.sun_path);
+          Error (buffer);
+          free(buffer);
+        }
+      else
+        Error ("Creating Unix socket");
+      
+       return -1;
     } 
 #ifdef BSD44SOCKETS
     if (bind(request, (struct sockaddr *)&unsock, SUN_LEN(&unsock)))
@@ -552,13 +597,27 @@ open_unix_socket ()
     if (bind(request, (struct sockaddr *)&unsock, strlen(unsock.sun_path)+2))
 #endif
     {
-	Error ("Binding Unix socket");
+      char *buffer;
+      int i;                                                                  
+      
+      i = strlen(unsock.sun_path);                                            
+      buffer = (char *)malloc(i + 80);                                                
+      if (buffer)
+        {
+          sprintf(buffer, "Error binding unix socket: %s\n", 
+                  unsock.sun_path);
+          Error (buffer);
+          free(buffer);
+        }
+      else
+        Error ("Creating Unix socket");
+      
 	close (request);
 	return -1;
     }
     if (listen (request, 5))
     {
-	Error ("Unix Listening");
+	Error ("Unix Listen");
 	close (request);
 	return -1;
     }
@@ -1350,7 +1409,7 @@ ClientAuthorized(client, proto_n, auth_proto, string_n, auth_string)
 				  string_n, auth_string);
 
     priv = (OsCommPtr)client->osPrivate;
-    if (auth_id == (AuID) ~0L && !allow_any_host)
+    if (auth_id == (AuID) ~0L && !NasConfig.AllowAny)
     {
 	if (getpeername (priv->fd, &from.sa, &fromlen) != -1)
 	{
